svn commit: samba r9092 - in branches/SAMBA_4_0/source/script: .

tpot at samba.org tpot at samba.org
Fri Aug 5 01:23:35 GMT 2005


Author: tpot
Date: 2005-08-05 01:23:35 +0000 (Fri, 05 Aug 2005)
New Revision: 9092

WebSVN: http://websvn.samba.org/cgi-bin/viewcvs.cgi?view=rev&root=samba&rev=9092

Log:
Generate some more stub functions.

Modified:
   branches/SAMBA_4_0/source/script/build_smb_interfaces.pl


Changeset:
Modified: branches/SAMBA_4_0/source/script/build_smb_interfaces.pl
===================================================================
--- branches/SAMBA_4_0/source/script/build_smb_interfaces.pl	2005-08-05 01:23:33 UTC (rev 9091)
+++ branches/SAMBA_4_0/source/script/build_smb_interfaces.pl	2005-08-05 01:23:35 UTC (rev 9092)
@@ -87,12 +87,40 @@
 
 print FILE "/* EJS wrapper functions auto-generated by build_smb_interfaces.pl */\n\n";
 
 # Top level functions
 
 foreach my $x (@{$header}) {
+
   next, if $x->{STRUCT_NAME} eq "";
+
+  print FILE "static NTSTATUS ejs_pull_$x->{STRUCT_NAME}(struct ejs_rpc *ejs, struct MprVar *v, struct $x->{STRUCT_NAME} *r)\n";
+  print FILE "{\n";
+  print FILE "\tNDR_CHECK(ejs_pull_struct_start(ejs, &v, \"input\"));\n";
+  print FILE "\treturn NT_STATUS_OK;\n";
+  print FILE "}\n\n";
+
+  print FILE "static NTSTATUS ejs_push_$x->{STRUCT_NAME}(struct ejs_rpc *ejs, struct MprVar *v, const struct $x->{STRUCT_NAME} *r)\n\n";
+  print FILE "{\n";
+  print FILE "\tNDR_CHECK(ejs_push_struct_start(ejs, &v, \"output\"));\n";
+
+  print FILE "\treturn NT_STATUS_OK;\n";
+  print FILE "}\n\n";
+}
+
+# Top level call functions
+
+foreach my $x (@{$header}) {
+  next, if $x->{STRUCT_NAME} eq "";
+
+  $raw_name = $x->{STRUCT_NAME};
+  $raw_name =~ s/smb_/smb_raw_/;
+
   print FILE "static int ejs_$x->{STRUCT_NAME}(int eid, int argc, struct MprVar **argv)\n";
   print FILE "{\n";
+  print FILE "\tstruct $x->{STRUCT_NAME} parms;\n\n";
+
+  print FILE "\t$raw_name(tree, &params);\n";
+
   print FILE "\tejsSetErrorMsg(eid, \"Not implemented\");\n";
   print FILE "\treturn -1;\n";
   print FILE "}\n\n";
@@ -87,12 +87,40 @@
 print FILE "/* EJS wrapper functions auto-generated by build_smb_interfaces.pl */\n\n";
 
-# Top level functions
+# Top level push/pull functions
 
 foreach my $x (@{$header}) {



More information about the samba-cvs mailing list